==> 0ad_0.27.0.orig.tar.xz: 0ad-0.27.0/README.md <==
# 0 A.D. Introductory Information

[![FreeBSD Build Status](https://jenkins.wildfiregames.com/job/0ad-freebsd/job/main/badge/icon?subject=FreeBSD&style=plastic)](https://jenkins.wildfiregames.com/job/0ad-freebsd/job/main/)
[![Linux Build Status](https://jenkins.wildfiregames.com/job/0ad-linux/job/main/badge/icon?subject=Linux&style=plastic)](https://jenkins.wildfiregames.com/job/0ad-linux/job/main/)
[![macOS Build Status](https://jenkins.wildfiregames.com/job/0ad-macos/job/main/badge/icon?subject=macOS&style=plastic)](https://jenkins.wildfiregames.com/job/0ad-macos/job/main/)
[![Windows Build Status](https://jenkins.wildfiregames.com/job/0ad-windows/job/main/badge/icon?subject=Windows&style=plastic)](https://jenkins.wildfiregames.com/job/0ad-windows/job/main/)

[![Game References Checks Status](https://gitea.wildfiregames.com/0ad/0ad/actions/workflows/checkrefs.yml/badge.svg?branch=main)](https://gitea.wildfiregames.com/0ad/0ad/actions?workflow=checkrefs.yml)
[![Pre-commit Checks Status](https://gitea.wildfiregames.com/0ad/0ad/actions/workflows/pre-commit.yml/badge.svg?branch=main)](https://gitea.wildfiregames.com/0ad/0ad/actions?workflow=pre-commit.yml)

0 A.D. (pronounced "zero ey-dee") is a free, open-source, cross-platform
real-time strategy game of ancient warfare.

This is currently an incomplete, under-development version of the game.
We're always interested in getting more people involved, to help bring the game
towards completion and to share the interesting experience of developing a
project of this scope.

There are several ways to contact us and find more information:

- Web site: https://play0ad.com/
- Forums: https://www.wildfiregames.com/forum/
- Gitea (development info, bug tracker): https://gitea.wildfiregames.com/
- IRC: #0ad on irc.quakenet.org

## Running precompiled binaries on Windows

A precompiled, ready-to-play development version of the game is available from
a checkout of the `nightly-build` SVN repository. If you are using the git
repository, you have to follow [the steps below](#compiling-the-game-from-source-code).

In a checkout of the `nightly-build` SVN repository, open the "binaries\system" folder.

- To launch the game: Run pyrogenesis.exe
- To launch the map editor: Run Atlas.bat or "pyrogenesis.exe -editor"

## Compiling the game from source code

The instructions for compiling the game on Windows, Linux and OS X are at
[BuildInstructions](https://gitea.wildfiregames.com/0ad/0ad/wiki/BuildInstructions).

## Reporting problems

Bugs should be reported on Gitea. For information on reporting problems
and finding logs, see [ReportingErrors](https://gitea.wildfiregames.com/0ad/0ad/wiki/ReportingErrors).

## Contributing Code

If you want to help out programming for the game, have a look at
[GettingStartedProgrammers](https://gitea.wildfiregames.com/0ad/0ad/wiki/GettingStartedProgrammers)
or contact us on #0ad-dev on irc.quakenet.org

## Contributing Artwork

If you want to make artwork for the game, have a look at
[For Artists](https://gitea.wildfiregames.com/0ad/0ad/wiki#for-artists)
or visit [the forums](https://www.wildfiregames.com/forum).

## Translating

You can help translating the game at https://www.transifex.com/projects/p/0ad
for more information, see [Localization](https://gitea.wildfiregames.com/0ad/0ad/wiki/Localization)

==> 0ad_0.28.0.orig.tar.xz: 0ad-0.28.0/README.md <==
# 0 A.D. Introductory Information

[![FreeBSD Build Status](https://jenkins.wildfiregames.com/job/0ad-freebsd/job/main/badge/icon?subject=FreeBSD&style=plastic)](https://jenkins.wildfiregames.com/job/0ad-freebsd/job/main/)
[![Linux Build Status](https://jenkins.wildfiregames.com/job/0ad-linux/job/main/badge/icon?subject=Linux&style=plastic)](https://jenkins.wildfiregames.com/job/0ad-linux/job/main/)
[![macOS Build Status](https://jenkins.wildfiregames.com/job/0ad-macos/job/main/badge/icon?subject=macOS&style=plastic)](https://jenkins.wildfiregames.com/job/0ad-macos/job/main/)
[![Windows Build Status](https://jenkins.wildfiregames.com/job/0ad-windows/job/main/badge/icon?subject=Windows&style=plastic)](https://jenkins.wildfiregames.com/job/0ad-windows/job/main/)

[![Game References Checks Status](https://gitea.wildfiregames.com/0ad/0ad/actions/workflows/checkrefs.yml/badge.svg?branch=main)](https://gitea.wildfiregames.com/0ad/0ad/actions?workflow=checkrefs.yml)
[![Pre-commit Checks Status](https://gitea.wildfiregames.com/0ad/0ad/actions/workflows/pre-commit.yml/badge.svg?branch=main)](https://gitea.wildfiregames.com/0ad/0ad/actions?workflow=pre-commit.yml)

[![Bi-Weekly Bundles Status](https://jenkins.wildfiregames.com/job/0ad-bundles/badge/icon?subject=Bi-Weekly%20Bundles&style=plastic)](https://jenkins.wildfiregames.com/job/0ad-bundles)
[![Technical Docs Status](https://jenkins.wildfiregames.com/job/0ad-technical-docs/badge/icon?subject=Technical%20Docs&style=plastic)](https://docs.wildfiregames.com/)
[![Nightly Build Status](https://jenkins.wildfiregames.com/job/0ad-nightly/badge/icon?subject=Nightly%20Build&style=plastic)](https://gitea.wildfiregames.com/0ad/0ad/wiki/NightlyBuild)

0 A.D. (pronounced "zero ey-dee") is a free, open-source, cross-platform
real-time strategy game of ancient warfare.

This is currently an incomplete, under-development version of the game.
We're always interested in getting more people involved, to help bring the game
towards completion and to share the interesting experience of developing a
project of this scope.

There are several ways to contact us and find more information:

- Web site: https://play0ad.com/
- Forums: https://www.wildfiregames.com/forum/
- Gitea (development info, bug tracker): https://gitea.wildfiregames.com/
- IRC: #0ad on irc.quakenet.org

## Running precompiled binaries on Windows

A precompiled, ready-to-play development version of the game is available from
a checkout of the `nightly-build` SVN repository. If you are using the git
repository, you have to follow [the steps below](#compiling-the-game-from-source-code).

In a checkout of the `nightly-build` SVN repository, open the "binaries\system" folder.

- To launch the game: Run pyrogenesis.exe
- To launch the map editor: Run Atlas.bat or "pyrogenesis.exe -editor"

## Compiling the game from source code

The instructions for compiling the game on Windows, Linux and OS X are at
[BuildInstructions](https://gitea.wildfiregames.com/0ad/0ad/wiki/BuildInstructions).

## Reporting problems

Bugs should be reported on Gitea. For information on reporting problems
and finding logs, see [ReportingErrors](https://gitea.wildfiregames.com/0ad/0ad/wiki/ReportingErrors).

## Contributing Code

If you want to help out programming for the game, have a look at
[GettingStartedProgrammers](https://gitea.wildfiregames.com/0ad/0ad/wiki/GettingStartedProgrammers)
or contact us on #0ad-dev on irc.quakenet.org

## Contributing Artwork

If you want to make artwork for the game, have a look at
[For Artists](https://gitea.wildfiregames.com/0ad/0ad/wiki#for-artists)
or visit [the forums](https://www.wildfiregames.com/forum).

## Translating

You can help translating the game at https://www.transifex.com/projects/p/0ad
for more information, see [Localization](https://gitea.wildfiregames.com/0ad/0ad/wiki/Localization)
